==> maineetloire_20170122_0405.tgz: var/www/vhosts/mag.maine-et-loire.fr/htdocs/wp-content/themes/emag_new/single-aside.php <==
<?php get_header(); ?>

<?php
// Get option
$all_articles = get_field("articles_a_attacher");
$colors_category = get_option("category_colors");
$active_color = $colors_category[the_category_ID(false)];
$rbg_active_color = dh_hex2rgb($active_color);
$normal = "rgb(" . $rbg_active_color[0] . ", " . $rbg_active_color[1] . ", " . $rbg_active_color[2] . ");";
$dark = "rgba(" . $rbg_active_color[0] . ", " . $rbg_active_color[1] . ", " . $rbg_active_color[2] . ", 0.6);";
$category = get_the_category($post);
$libelle_post = (!empty(get_field("sous-titre"))) ? get_field("sous-titre") : $category[0]->name;
?>
<style>
    div.post-topic-child:nth-child(2n + 1){
        border-color: <?php echo $normal; ?> !important;
    }
    div.post-topic-child:nth-child(2n + 1) h5,
    div.post-topic-child:nth-child(2n + 1) h4 {
        color: <?php echo $normal; ?> !important;
    }

    div.post-topic-child:nth-child(2n){
        border-color: <?php echo $dark; ?> !important;
    }
    div.post-topic-child:nth-child(2n) h5,
    div.post-topic-child:nth-child(2n) h4 {
        color: <?php echo $dark; ?> !important;
    }

    h3{
        color: <?php echo $normal; ?> !important;
        font-size:20px;
    }
    h2{
        font-size:30px !important;
    }


    div.bg-repeat{
        background: url("<?php echo get_template_directory_uri(); ?>/img/bg_whitetrame.png") center fixed;
        width:100%;
        height:100%;
        position:fixed;
        display:block;
        left:0;
        top:0;
        z-index: -1;
    }

    .post-topic-child{
        width:297.5px!important;
        margin-left:1px!important;
        margin-right:1px!important;
    }

    main.container-topic{
        max-width:none!important;
    }

    /*main.container-topic section.wrapper-topic div.post-topic-content div.post-topic-content-wrap{
        width:inherit!important;
        display:inline-block!important;
        margin-left:auto!important;
        margin-right:auto!important;
    }

    .wrapper-topic{
        display:inline-block!important;
        margin-left:auto!important;
        margin-right:auto!important;
    }

    main.container-topic section.wrapper-topic h1.title-cat{
        position:relative!important;
        float:left;
    }*/

    .post-topic-content-wrap, .post-topic-title{
        margin-left:auto;
        margin-right:auto;
    }

</style>



<script>
    jQuery(document).ready(function ($) {

        // var width_topic = jQuery(".post-topic-title").width()
//    jQuery(".post-topic-title").width

        // var nb_subtopic = jQuery(".post-topic-child").length;

        // if (nb_subtopic == 1) {
        //     var largeur = 100;
        // }else if (nb_subtopic == 2) {
        //     var largeur = 49.8;
        // }else if (nb_subtopic == 3) {
        //     var largeur = 33.1;
        // }else{
        //    var largeur = 24.8;
        // }
        //     jQuery(".post-topic-child").css('width',largeur+'%');
        //     jQuery(".post-topic-child").css('margin','0 0.1% 0 0.1%');

        repositionner();
        $(window).resize(function () {
            repositionner();
        });
        function repositionner() {
            // alert('ok');
            nb_subtopic = jQuery(".post-topic-child").length;
            widthContainer = $(window).width() * 90 / 100;
            nbColumn = Math.floor(widthContainer / 300);
            widthCenter = nbColumn * 300;
            if (nbColumn <= nb_subtopic) {
                $('.post-topic-content-wrap').css('width', widthCenter + 'px');
                $('.post-topic-title').css('width', widthCenter + 'px');
                leftTitle = (widthContainer - widthCenter) / 2;
                $('.title-cat').css('left', leftTitle + 'px');
            }
        }

    });
</script>


<main role="main" class="container-topic">
    <section class="wrapper-topic">
        <h1 class="title-cat" style="background-color:<?php echo $active_color; ?>">
            <!-- <?php echo $libelle_post; ?> --><?php echo the_title(); ?>
        </h1>
        <?php
//        get(the_post());
        if (get_field("titre_de_larticle") != '' || get_field("chapo_de_larticle") != '') {
            ?>
            <div class="post-topic-title">
                <?php if (get_field("titre_de_larticle") != '') { ?>
                    <div class="cover-excerpt">
                        <h2><?php echo get_field("titre_de_larticle"); ?></h2>
                    </div>
                <?php } ?>
                <div style="clear:both;margin-top:20px;"></div>
                <?php
                if (get_field("chapo_de_larticle") != '') {
                    echo '<div style="text-align:left;">' . get_field("chapo_de_larticle") . '</div>';
                }
                ?>
            </div>
        <?php } ?>

        <div class="post-topic-content">
            <?php if ($all_articles) { ?>
                <div class="post-topic-content-wrap">
                    <?php foreach ($all_articles as $article) { ?>

                        <div class="post-topic-child">
                            <div class="post-topic-child-img">
                                <?php $post_thumbnail_url = wp_get_attachment_url($article); ?>
                                <a href="<?php echo $post_thumbnail_url; ?>" class="fancybox-button" rel="single-thumb"><?php echo get_the_post_thumbnail($article, 'full'); ?></a>
                            </div>

                            <h5 class="post-topic-child-subtitle">
                                <?php
                                echo get_field("sous-titre", $article->ID);
                                ?>
                            </h5>
                            <h4 class="post-topic-child-title">
                                <?php
                                echo $article->post_title;
                                ?>
                            </h4>

                            <div class="post-topic-child-content">
                                <?php
                                echo get_field("chapo_de_larticle", $article->ID);
                                echo "<p class='1'>" . apply_filters('the_content', $article->post_content) . "</p>";
                                ?>
                            </div>

                            <?php
                            $links = get_field("amorce", $article->ID);
                            if (!empty($links)) {
                                foreach ($links as $link) {
                                    ?>
                                    <div class="post-topic-child-link-out">
                                        <a href="<?php echo $link['url_amorce']; ?>" target="_blank">
                                            <span class="icone-en-savoir-plus"></span>
                                            <?php
                                            if ($link['titre_amorce']) {
                                                echo $link['titre_amorce'];
                                            } else {
                                                ?>En savoir plus<?php
                                            }
                                            ?>
                                        </a>
                                    </div>
                                    <?php
                                }
                            }
                            ?>
                        </div>
                <?php } ?>
                </div>
<?php } ?>
        </div>

        <div style="clear:both"></div>
        <br><br>
        <script>
            jQuery(document).ready(function () {

                jQuery('.post-topic-content-wrap').masonry({
                    itemSelector: '.post-topic-child',
                    columnWidth: '.post-topic-child',
                    percentPosition: true
                });
            });


        </script>
    </section>
</main>
<?php get_footer(); ?>

==> maineetloire_20170129_0405.tgz: var/www/vhosts/mag.maine-et-loire.fr/htdocs/wp-content/themes/emag_new/single-aside.php <==
<?php get_header(); ?>

<?php
// Get option
$all_articles = get_field("articles_a_attacher");
$colors_category = get_option("category_colors");
$active_color = $colors_category[the_category_ID(false)];
$rbg_active_color = dh_hex2rgb($active_color);
$normal = "rgb(" . $rbg_active_color[0] . ", " . $rbg_active_color[1] . ", " . $rbg_active_color[2] . ");";
$dark = "rgba(" . $rbg_active_color[0] . ", " . $rbg_active_color[1] . ", " . $rbg_active_color[2] . ", 0.6);";
$category = get_the_category($post);
$libelle_post = (!empty(get_field("sous-titre"))) ? get_field("sous-titre") : $category[0]->name;
?>
<style>
    div.post-topic-child:nth-child(2n + 1){
        border-color: <?php echo $normal; ?> !important;
    }
    div.post-topic-child:nth-child(2n + 1) h5,
    div.post-topic-child:nth-child(2n + 1) h4 {
        color: <?php echo $normal; ?> !important;
    }

    div.post-topic-child:nth-child(2n){
        border-color: <?php echo $dark; ?> !important;
    }
    div.post-topic-child:nth-child(2n) h5,
    div.post-topic-child:nth-child(2n) h4 {
        color: <?php echo $dark; ?> !important;
    }

    h3{
        color: <?php echo $normal; ?> !important;
        font-size:20px;
	padding:5px;
    }
    h2{
        font-size:30px !important;
    }


    div.bg-repeat{
        background: url("<?php echo get_template_directory_uri(); ?>/img/bg_whitetrame.png") center fixed;
        width:100%;
        height:100%;
        position:fixed;
        display:block;
        left:0;
        top:0;
        z-index: -1;
    }

    .post-topic-child{
        width:297.5px!important;
        margin-left:1px!important;
        margin-right:1px!important;
    }

    main.container-topic{
        max-width:none!important;
    }

    /*main.container-topic section.wrapper-topic div.post-topic-content div.post-topic-content-wrap{
        width:inherit!important;
        display:inline-block!important;
        margin-left:auto!important;
        margin-right:auto!important;
    }

    .wrapper-topic{
        display:inline-block!important;
        margin-left:auto!important;
        margin-right:auto!important;
    }

    main.container-topic section.wrapper-topic h1.title-cat{
        position:relative!important;
        float:left;
    }*/

    .post-topic-content-wrap, .post-topic-title{
        margin-left:auto;
        margin-right:auto;
    }

</style>



<script>
    jQuery(document).ready(function ($) {

        // var width_topic = jQuery(".post-topic-title").width()
//    jQuery(".post-topic-title").width

        // var nb_subtopic = jQuery(".post-topic-child").length;

        // if (nb_subtopic == 1) {
        //     var largeur = 100;
        // }else if (nb_subtopic == 2) {
        //     var largeur = 49.8;
        // }else if (nb_subtopic == 3) {
        //     var largeur = 33.1;
        // }else{
        //    var largeur = 24.8;
        // }
        //     jQuery(".post-topic-child").css('width',largeur+'%');
        //     jQuery(".post-topic-child").css('margin','0 0.1% 0 0.1%');

        repositionner();
        $(window).resize(function () {
            repositionner();
        });
        function repositionner() {
              //alert($(window).width());
            nb_subtopic = jQuery(".post-topic-child").length;
            widthContainer = $(window).width() * 90 / 100;
            nbColumn = Math.floor(widthContainer / 300);
            widthCenter = nbColumn * 300;
            if (nbColumn <= nb_subtopic) {
                $('.post-topic-content-wrap').css('width', widthCenter + 'px');
                $('.post-topic-title').css('width', widthCenter + 'px');
                leftTitle = Math.floor((widthContainer - widthCenter) / 2.7);
                $('.title-cat').css('left', leftTitle + 'px');
            }else if(nbColumn > nb_subtopic) {
		/*reste a continuer a calculer la largeur de title, content-wrap et les childs*/
		 $('.post-topic-title').css('width', widthCenter-(0.3 * widthCenter) + 'px');
                 $('.post-topic-content-wrap').css('width', widthCenter-(0.3 * widthCenter) + 'px');
		 $('.post-topic-child').attr('style','width:313px !important');
		 leftTitle = Math.floor(((widthContainer - widthCenter) / 2)*1.74);
                 $('.title-cat').css('left', leftTitle + 'px');
	     }

	     if(nb_subtopic < 2){
		/*reste a continuer a calculer la largeur de title, content-wrap et les childs*/
		 $('.post-topic-title').css('width', 315 + 'px');
                 $('.post-topic-content-wrap').css('width', 315 + 'px');
		 leftTitle = Math.floor(((widthContainer - widthCenter) / 2)*2.9);
                 $('.title-cat').css('left', leftTitle + 'px');
            }
        }

    });
</script>


<main role="main" class="container-topic">
    <section class="wrapper-topic">
        <h1 class="title-cat" style="background-color:<?php echo $active_color; ?>">
            <!-- <?php echo $libelle_post; ?> --><?php echo the_title(); ?>
        </h1>
        <?php
//        get(the_post());
        if (get_field("titre_de_larticle") != '' || get_field("chapo_de_larticle") != '') {
            ?>
	 <div class="post-topic-title">
		<!--start chapo_container -->
 		<div id="chapo_container">
                <?php if (get_field("titre_de_larticle") != '') { ?>
                    <div class="cover-excerpt">
                        <h2><?php echo get_field("titre_de_larticle"); ?></h2>
                    </div>
                <?php } ?>
                <div style="clear:both;margin-top:20px;"></div>
                <?php
                if (get_field("chapo_de_larticle") != '') {
                    echo '<div style="text-align:left;">' . get_field("chapo_de_larticle") . '</div>';
                }
                ?>
		</div>
		<!--end chapo_container -->

            </div>
        <?php } ?>

        <div class="post-topic-content">
            <?php if ($all_articles) { ?>
                <div class="post-topic-content-wrap">
                    <?php foreach ($all_articles as $article) { ?>

                        <div class="post-topic-child">
                            <div class="post-topic-child-img">
                                <?php $post_thumbnail_url = wp_get_attachment_url($article); ?>
                                <a href="<?php echo $post_thumbnail_url; ?>" class="fancybox-button" rel="single-thumb"><?php echo get_the_post_thumbnail($article, 'full'); ?></a>
                            </div>

                            <h5 class="post-topic-child-subtitle">
                                <?php
                                echo get_field("sous-titre", $article->ID);
                                ?>
                            </h5>
                            <h4 class="post-topic-child-title">
                                <?php
                                echo $article->post_title;
                                ?>
                            </h4>

                            <div class="post-topic-child-content">
                                <?php
                                echo get_field("chapo_de_larticle", $article->ID);
                                echo "<p class='1'>" . apply_filters('the_content', $article->post_content) . "</p>";
                                ?>
                            </div>

                            <?php
                            $links = get_field("amorce", $article->ID);
                            if (!empty($links)) {
                                foreach ($links as $link) {
                                    ?>
                                    <div class="post-topic-child-link-out">
                                        <a href="<?php echo $link['url_amorce']; ?>" target="_blank">
                                            <span class="icone-en-savoir-plus"></span>
                                            <?php
                                            if ($link['titre_amorce']) {
                                                echo $link['titre_amorce'];
                                            } else {
                                                ?>En savoir plus<?php
                                            }
                                            ?>
                                        </a>
                                    </div>
                                    <?php
                                }
                            }
                            ?>
                        </div>
                <?php } ?>
                </div>
<?php } ?>
        </div>

        <div style="clear:both"></div>
        <br><br>
        <script>
            jQuery(window).on('load',function () {

                jQuery('.post-topic-content-wrap').masonry({
                    itemSelector: '.post-topic-child',
                    columnWidth: '.post-topic-child',
                    percentPosition: true
                });
		

            });


        </script>
    </section>
</main>
<?php get_footer(); ?>
